<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Skjulte genveje</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Disse predefinerede genveje vil blive tilsidesat hvis de også er tildelt andre handlinger i Indstillinger → Genveje.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Genvej</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Luk vindue eller forlad fuld skærm</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Næste billede</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Mellemrum</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Sidste billede</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Forrige billede</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Første billede</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="97"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Start med fuld skærm (kan være nyttigt ved en flisebelagt vindueshåndtering)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Tag et skærmbillede (forældet, brug venligst Screengrab i stedet)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>DIR</source>
        <translation>MAPPE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Tag et skærmaftryk og gem det i mappen uden at vise brugerfladen (forældet, brug venligst Screengrab i stedet)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="120"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FIL1, FIL2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>ukendt svar ved fejl</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>ukendt svar ved fejl</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>A simple and fast image viewer</source>
        <translation>En simpel og hurtig billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Copyright (C) </source>
        <translation>Ophavsret (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LXQt Project</source>
        <translation>LXQt Project</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Development: </source>
        <translation>Udvikling: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Author: </source>
        <translation>Udvikler: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Open File</source>
        <translation>Åbn fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Image files (%1)</source>
        <translation>Billedfiler (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Open directory</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Save File</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="730"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>%1/%2 Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Indlæser...) - Billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Kunne ikke indlæse) - Billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>Thumbnails</source>
        <translation>Miniaturer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1492"/>
        <source>EXIF Data</source>
        <translation>EXIF-data</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Ryd</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Brug en ændringstast til at rydde en genvej
i redigeringstilstanden.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="343"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Advarsel: Flertydig genvej registreret!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="360"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Flertydig genvej ikke accepteret.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Kan ikke gemme med dette billedformat!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="48"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="136"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="139"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="142"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="149"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Billedfremviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="709"/>
        <source>Annotations Toolbar</source>
        <translation>Kommenteringsværktøjslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Åbn &amp;med...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Sorting</source>
        <translation>Sortering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Skjulte &amp;Genveje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>&amp;Open…</source>
        <translation>&amp;Åbn…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Genindlæs fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>&amp;Save</source>
        <translation>&amp;Gem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Save &amp;As</source>
        <translation>Gem &amp;Som</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;Ind</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;ud</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Kopiér til Udklipsholder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Next File</source>
        <translation>Næste fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="356"/>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Previous File</source>
        <translation>Forrige fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Original Size</source>
        <translation>Original størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>&amp;Fit</source>
        <translation>&amp;Tilpas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Rotér med uret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rotér &amp;mod uret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>L</source>
        <translation>Skift-R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>P&amp;references</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>&amp;Print</source>
        <translation>&amp;Udskriv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>First File</source>
        <translation>Første fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Last File</source>
        <translation>Sidste fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nyt vindue</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Vend &amp;vandret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>H</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Capture Screenshot</source>
        <translation>Tag skærmaftryk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Fuldskærm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>Flip &amp;Vertically</source>
        <translation>Spejl &amp;lodret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>V</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Indsæt fra Udklipsholder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diasshow</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Show Thumbnails</source>
        <translation>Vis miniaturer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>T</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>File Properties</source>
        <translation>Filegenskaber</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Open &amp;Directory</source>
        <translation>Åbn &amp;mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Upload the image</source>
        <translation>Upload billedet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="598"/>
        <source>Show EXIF Data</source>
        <translation>Vis EXIF-data</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>No Tool</source>
        <translation>Intet værktøj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Deselect all drawing tools</source>
        <translation>Fravælg alle tegnefunktioner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Draw Arrow</source>
        <translation>Tegn pil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Draw an arrow</source>
        <translation>Tegn en pil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Draw Rectangle</source>
        <translation>Tegn et rektangel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Draw a hollow rectangle</source>
        <translation>Tegn et hult rektangel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <source>Draw Circle</source>
        <translation>Tegn en cirkel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Draw a hollow circle</source>
        <translation>Tegn en hul cirkel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Draw Number</source>
        <translation>Indsæt et tal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="673"/>
        <source>Draw incrementing numbers</source>
        <translation>Indsæt et stigende tal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Menubar</source>
        <translation>Menulinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Hovedværktøjslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="698"/>
        <source>Main Toolbar</source>
        <translation>Hovedværktøjslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Kommenteringsværktøjslinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Show Outline</source>
        <translation>Vis omrids</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>O</source>
        <translation>o</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopiér &amp;sti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Copy path</source>
        <translation>Kopiér sti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <location filename="../mainwindow.ui" line="745"/>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="748"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Resize</source>
        <translation>Tilpas størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Efter filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>By File Name</source>
        <translation>Efter filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>By &amp;Modification Time</source>
        <translation>Efter &amp;Ændringstid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>By Modification Time</source>
        <translation>Efter ændringstid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>By C&amp;reation Time</source>
        <translation>Efter op&amp;rettelsestidspunkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>By Creation Time</source>
        <translation>Efter oprettelsetidspunkt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>By File &amp;Size</source>
        <translation>Efter fil&amp;størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>By File Size</source>
        <translation>Efter filstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="809"/>
        <source>By File &amp;Type</source>
        <translation>Efter Fil &amp;Type</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>By File Type</source>
        <translation>Efter filtype</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="817"/>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="820"/>
        <source>Ctrl+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Ctrl+Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <source>First Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Last Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Solid Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Go</source>
        <translation>Gå</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>Toolbar</source>
        <translation>Værktøjslinje</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Ikontema:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Filstørrelsesgrænse for miniaturer:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Normal baggrundsfarve:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Baggrundsfarve i fuldskærm:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Højeste antal seneste filer:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interval for diasshow (sekunder):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Show image outline by default</source>
        <translation>Vis omrids på billede som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Vis kommenteringsværktøjslinje som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Fit images when navigating</source>
        <translation>Tilpas billeder når der navigeres</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensioner på miniaturebillede:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Brug systemets papirkurv (Spørg ikke brugeren)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Vis miniaturedok som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Vis Exif-data som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Vis menulinje som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Vis hoved værtøjslinje som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Billede</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Vil måske kun fungere med billeder der har gyldigt farverum.
Genindlæs nuværende billede for at se effekten.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Farverum:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (understøttet af de fleste skærme)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>Lineær sRGB (lineær gamma)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (skærme med bredt spektrum)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Solid background by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="263"/>
        <source>Smooth images on zooming</source>
        <translation>Udjævn billeder ved zoom</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="271"/>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="290"/>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="295"/>
        <source>Shortcut</source>
        <translation>Genvej</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="303"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Tilpas størrelsen på billedet</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Højde</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Nuværende størrelse:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Ny størrelse:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Bevar højde-/breddeforhold</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Skærmaftryk</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Tag et skærmaftryk</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Område</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Hele skærmen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Kun nuværende vindue</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Indfang et område af skærmen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inkluder musemarkør</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sek.</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Forsinkelse:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inkluder vinduets titel og ramme</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
</context>
</TS>
